@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Barcode Utilities
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 # import re
 
