@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2014 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,22 +20,23 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
-``rattail.batches`` -- Batch System
+Batch System
 """
 
-from .exceptions import *
-from .providers import *
-from ..util import load_entry_points
+from __future__ import unicode_literals
+
+from rattail.util import load_entry_points
+from rattail.batches.providers import BatchProvider
+from rattail.batches.exceptions import *
 
 
-def get_provider(name):
+def get_provider(config, name):
     providers = get_providers()
     provider = providers.get(name)
     if not provider:
         raise BatchProviderNotFound(name)
-    return provider()
+    return provider(config)
 
 
 def get_providers():
