@@ -26,4 +26,5 @@ Console Commands
 
 from __future__ import unicode_literals, absolute_import
 
-from .core import main, Command, Subcommand, ImportSubcommand, NewImportSubcommand, Dump, date_argument
+from .core import main, Command, Subcommand, OldImportSubcommand, NewImportSubcommand, Dump, date_argument
+from .importing import ImportSubcommand
