@@ -280,51 +280,6 @@ class Subcommand(object):
         raise NotImplementedError
 
 
-class AddUser(Subcommand):
-    """
-    Adds a user to the database.
-    """
-
-    name = 'adduser'
-    description = "Add a user to the database."
-
-    def add_parser_args(self, parser):
-        parser.add_argument('username',
-                            help="Username for the new account.")
-        parser.add_argument('-A', '--administrator',
-                            action='store_true',
-                            help="Add the new user to the Administrator role.")
-
-    def run(self, args):
-        from rattail.db import Session
-        from rattail.db import model
-        from rattail.db.auth import set_user_password, administrator_role
-
-        session = Session()
-
-        if session.query(model.User).filter_by(username=args.username).count():
-            session.close()
-            self.stderr.write("User '{0}' already exists.\n".format(args.username))
-            return
-
-        passwd = ''
-        while not passwd:
-            try:
-                passwd = getpass("Enter a password for user '{0}': ".format(args.username))
-            except KeyboardInterrupt:
-                self.stderr.write("\nOperation was canceled.\n")
-                return
-
-        user = model.User(username=args.username)
-        set_user_password(user, passwd)
-        if args.administrator:
-            user.roles.append(administrator_role(session))
-        session.add(user)
-        session.commit()
-        session.close()
-        self.stdout.write("Created user: {0}\n".format(args.username))
-
-
 class CloneDatabase(Subcommand):
     """
     Clone data from any source database into any target database.
@@ -418,33 +373,16 @@ class DataSync(Subcommand):
         parser.add_argument('-D', '--do-not-daemonize',
                             action='store_false', dest='daemonize', default=True,
                             help="Do not daemonize when starting.")
+        parser.add_argument('-T', '--timeout', metavar='MINUTES', type=int, default=0,
+                            help="Optional timeout (in minutes) for use with the 'wait' command.  "
+                            "If specified, the waiting still stop after the given number of minutes "
+                            "and exit with a nonzero code to indicate failure.")
 
     def run(self, args):
         from rattail.datasync.daemon import DataSyncDaemon
 
         if args.subcommand == 'wait':
-            log.debug("will wait for current change queue to clear")
-            last_logged = datetime.datetime.utcnow()
-            Session = self.parent.db_session_factory
-            model = self.parent.db_model
-            session = Session()
-            changes = session.query(model.DataSyncChange)
-            count = changes.count()
-            log.debug("there are {0} changes in the queue".format(count))
-            while count:
-                try:
-                    now = datetime.datetime.utcnow()
-                    if (now - last_logged).seconds >= 60:
-                        log.debug("still waiting, {0} changes in the queue".format(count))
-                        last_logged = now
-                    time.sleep(1)
-                    count = changes.count()
-                except KeyboardInterrupt:
-                    self.stderr.write("Waiting cancelled by user\n")
-                    session.close()
-                    sys.exit(1)
-            session.close()
-            log.debug("all changes have been processed")
+            self.wait(args)
 
         else: # manage the daemon
             daemon = DataSyncDaemon(args.pidfile, config=self.config)
@@ -459,6 +397,40 @@ class DataSync(Subcommand):
                     else:
                         raise
 
+    def wait(self, args):
+        model = self.parent.db_model
+        Session = self.parent.db_session_factory
+        session = Session()
+        started = datetime.datetime.utcnow()
+        log.debug("will wait for current change queue to clear")
+        last_logged = started
+
+        changes = session.query(model.DataSyncChange)
+        count = changes.count()
+        log.debug("there are {} changes in the queue".format(count))
+        while count:
+            try:
+                now = datetime.datetime.utcnow()
+
+                if args.timeout and (now - started).seconds >= (args.timeout * 60):
+                    log.warning("datasync wait timed out after {} minutes, with {} changes in queue".format(args.timeout, count))
+                    sys.exit(1)
+
+                if (now - last_logged).seconds >= 60:
+                    log.debug("still waiting, {} changes in the datasync queue".format(count))
+                    last_logged = now
+
+                time.sleep(1)
+                count = changes.count()
+
+            except KeyboardInterrupt:
+                self.stderr.write("Waiting cancelled by user\n")
+                session.close()
+                sys.exit(1)
+
+        session.close()
+        log.debug("all datasync changes have been processed")
+
 
 class EmailBouncer(Subcommand):
     """
@@ -739,7 +711,7 @@ class FileMonitorCommand(Subcommand):
                 service.delayed_auto_start_service(name)
 
 
-class ImportSubcommand(Subcommand):
+class OldImportSubcommand(Subcommand):
     """
     Base class for subcommands which use the data importing system.
     """
@@ -960,33 +932,7 @@ class NewImportSubcommand(Subcommand):
         handler.import_data(models, args)
 
 
-class ImportRattail(NewImportSubcommand):
-    """
-    Import data from another Rattail database.
-    """
-    name = 'import-rattail'
-    description = __doc__.strip()
-
-    def get_handler_factory(self, args):
-        spec = self.config.get('rattail.importing', 'rattail.handler',
-                               default='rattail.db.newimporting.rattail:RattailImportHandler')
-        return load_object(spec)
-
-    def add_parser_args(self, parser):
-        super(ImportRattail, self).add_parser_args(parser)
-        parser.add_argument('--dbkey', metavar='KEY', default='host',
-                            help="Config key for database engine to be used as the Rattail "
-                            "\"host\", i.e. the source of the data to be imported.  This key "
-                            "must be defined in the [rattail.db] section of your config file.  "
-                            "Defaults to 'host'.")
-
-    def get_handler_kwargs(self, args, **kwargs):
-        if args:
-            kwargs['dbkey'] = args.dbkey
-        return kwargs
-
-
-class ImportCSV(ImportSubcommand):
+class ImportCSV(OldImportSubcommand):
     """
     Import data from a CSV file.
     """
@@ -1010,38 +956,6 @@ class ImportCSV(ImportSubcommand):
         log.info("added or updated {0} {1} records".format(affected, provider.model_name))
 
 
-class InitializeDatabase(Subcommand):
-    """
-    Creates the initial Rattail tables within a database.
-    """
-
-    name = 'initdb'
-    description = "Create initial tables in a database."
-
-    def add_parser_args(self, parser):
-        parser.add_argument('--with-admin', action='store_true',
-                            help="Create an 'admin' user account if none exists.")
-
-    def run(self, args):
-        from alembic.util import obfuscate_url_pw
-        from rattail.db import model, auth, Session
-
-        # Maybe create 'admin' user with 'admin' password.
-        if args.with_admin:
-            session = Session()
-            if not session.query(model.User).filter_by(username='admin').count():
-                admin = model.User(username='admin')
-                auth.set_user_password(admin, 'admin')
-                admin.roles.append(auth.administrator_role(session))
-                session.add(admin)
-                self.stdout.write("[rattail] created 'admin' user with password 'admin'\n")
-                session.commit()
-            session.close()
-
-        self.stdout.write("[rattail] initialized schema for database: {0}\n".format(
-            obfuscate_url_pw(self.config.rattail_engine.url)))
-
-
 class LoadHostDataCommand(Subcommand):
     """
     Loads data from the Rattail host database, if one is configured.
@@ -1063,24 +977,150 @@ class LoadHostDataCommand(Subcommand):
         proc.load_all_data(engines['host'], Progress)
 
 
-class MakeUserCommand(Subcommand):
+class MakeAppDir(Subcommand):
     """
-    Creates a system user for Rattail.
+    Create a conventional 'app' dir for a virtual environment
     """
-    name = 'make-user'
-    description = "Create a system user account for Rattail"
+    name = 'make-appdir'
+    description = __doc__.strip()
 
     def add_parser_args(self, parser):
-        parser.add_argument('-U', '--username', metavar='USERNAME', default='rattail',
-                            help="Username for the new user; defaults to 'rattail'.")
-        parser.add_argument('--full-name', metavar='FULL_NAME',
-                            help="Full (display) name for the new user.")
-        parser.add_argument('--comment', metavar='COMMENT',
-                            help="Comment string for the new user.")
+        parser.add_argument('--path', metavar='PATH',
+                            help="Path where the app folder is to be established.  If not "
+                            "specified, a default will be assumed based on the virtual "
+                            "environment, e.g. '/envs/rattail/app'.")
+        parser.add_argument('-U', '--user', metavar='USERNAME',
+                            help="Linux username which should be given ownership to the various "
+                            "data folders which are to be created.  This is used when the app(s) "
+                            "are to normally be ran as the 'rattail' user for instance.  Use "
+                            "of this option probably requires 'sudo' or equivalent.")
 
     def run(self, args):
+        import pwd
+
+        if args.path:
+            app_path = os.path.abspath(args.path)
+            if os.path.basename(app_path) != 'app':
+                app_path = os.path.join(app_path, 'app')
+        else:
+            app_path = os.path.join(sys.prefix, 'app')
+        app_path = app_path.rstrip('/')
+
+        if not os.path.exists(app_path):
+            os.mkdir(app_path)
+
+        if args.user:
+            pwdata = pwd.getpwnam(args.user)
+        for name in ['batch', 'log', 'sessions', 'work']:
+            path = os.path.join(app_path, name)
+            if not os.path.exists(path):
+                os.mkdir(path)
+            if args.user:
+                os.chown(path, pwdata.pw_uid, pwdata.pw_gid)
+
+        self.stdout.write("Rattail app dir generated at: {}\n".format(app_path))
+
+
+class MakeConfig(Subcommand):
+    """
+    Generate stub config file(s) where you want them
+    """
+    name = 'make-config'
+    description = __doc__.strip()
+
+    def add_parser_args(self, parser):
+        parser.add_argument('-T', '--type', metavar='NAME', default='rattail',
+                            help="Type of config file to create; defaults to 'rattail' "
+                            "which will generate 'rattail.conf'")
+        parser.add_argument('-O', '--output', metavar='PATH', default='.',
+                            help="Path where the config file is to be generated.  This can "
+                            "be the full path including filename, or just the folder, in which "
+                            "case the filename is inferred from 'type'.  Default is to current "
+                            "working folder.")
+
+    def run(self, args):
+        from rattail.files import resource_path
+
+        template_path = resource_path('rattail:data/config/{}.conf'.format(args.type))
+        if not os.path.exists(template_path):
+            self.stderr.write("config template not found: {}".format(template_path))
+            sys.exit(1)
+
+        output_path = os.path.abspath(args.output)
+        if os.path.isdir(output_path):
+            output_path = os.path.join(output_path, os.path.basename(template_path))
+
+        shutil.copy(template_path, output_path)
+        self.stdout.write("Config file generated at: {}\n".format(output_path))
+
+
+class MakeUser(Subcommand):
+    """
+    Create a new user account in a given system
+    """
+    name = 'make-user'
+    description = __doc__.strip()
+
+    def add_parser_args(self, parser):
+        parser.add_argument('username',
+                            help="Username for the new user.")
+        parser.add_argument('--system', default='rattail',
+                            help="System in which to create the new user; defaults to "
+                            "rattail; must be one of: rattail, windows")
+        parser.add_argument('-A', '--admin', action='store_true',
+                            help="Whether the new user should have admin rights within "
+                            "the system (if applicable).")
+        parser.add_argument('--full-name',
+                            help="Full (display) name for the new user (if applicable).")
+        parser.add_argument('--comment',
+                            help="Comment string for the new user (if applicable).")
+
+    def run(self, args):
+        mkuser = getattr(self, 'mkuser_{}'.format(args.system), None)
+        if mkuser:
+            if mkuser(args):
+                self.stdout.write("created new user in '{}' system: {}\n".format(
+                    args.system, args.username))
+        else:
+            self.stderr.write("don't know how to make user for '{}' system\n".format(args.system))
+            sys.exit(1)
+
+    def user_exists(self, args):
+        self.stdout.write("user already exists in '{}' system: {}\n".format(
+            args.system, args.username))
+        sys.exit(1)
+
+    def obtain_password(self):
+        try:
+            password = None
+            while not password:
+                password = getpass(b"enter password for new user: ").strip()
+        except KeyboardInterrupt:
+            self.stderr.write("\noperation canceled by user\n")
+            sys.exit(2)
+        return password
+
+    def mkuser_rattail(self, args):
+        from rattail.db import auth
+
+        session = self.parent.db_session_factory()
+        model = self.parent.db_model
+        if session.query(model.User).filter_by(username=args.username).count():
+            session.close()
+            return self.user_exists(args)
+
+        user = model.User(username=args.username)
+        auth.set_user_password(user, self.obtain_password())
+        if args.admin:
+            user.roles.append(auth.administrator_role(session))
+        session.add(user)
+        session.commit()
+        session.close()
+        return True
+
+    def mkuser_windows(self, args):
         if sys.platform != 'win32':
-            sys.stderr.write("Sorry, only win32 platform is supported.\n")
+            self.stderr.write("sorry, only win32 platform is supported\n")
             sys.exit(1)
 
         from rattail.win32 import users
@@ -1089,20 +1129,23 @@ class MakeUserCommand(Subcommand):
         require_elevation()
 
         if users.user_exists(args.username):
-            sys.stderr.write("User already exists: {0}\n".format(args.username))
-            sys.exit(1)
+            return self.user_exists(args)
 
-        try:
-            password = None
-            while not password:
-                password = getpass(b"Enter a password: ").strip()
-        except KeyboardInterrupt:
-            sys.stderr.write("Operation canceled by user.")
-            sys.exit(2)
+        return users.create_user(args.username, self.obtain_password(),
+                                 full_name=args.full_name, comment=args.comment)
 
-        users.create_user(args.username, password,
-                          full_name=args.full_name, comment=args.comment)
-        sys.stdout.write("Created user: {0}\n".format(args.username))
+
+class MakeUUID(Subcommand):
+    """
+    Generate a new UUID
+    """
+    name = 'make-uuid'
+    description = __doc__.strip()
+
+    def run(self, args):
+        from rattail.core import get_uuid
+
+        self.stdout.write("{}\n".format(get_uuid()))
 
 
 class PalmCommand(Subcommand):
@@ -1163,8 +1206,8 @@ class PurgeBatchesCommand(Subcommand):
                             "none is specified, the current date is assumed.")
 
     def run(self, args):
+        from alembic.util import obfuscate_url_pw
         from rattail.db import Session
-        from rattail.db.util import obfuscate_url_pw
         from rattail.db.batches import util
 
         log.info("purging batches from database: {0}".format(obfuscate_url_pw(Session.kw['bind'].url)))
