@@ -29,6 +29,7 @@ from __future__ import unicode_literals, absolute_import
 import os
 import sys
 import shlex
+import datetime
 import ConfigParser
 import warnings
 import logging
@@ -65,8 +66,8 @@ def parse_list(value):
         return []
     # Per the shlex docs (https://docs.python.org/2/library/shlex.html):
     # "Prior to Python 2.7.3, this module did not support Unicode input."
-    if sys.version_info < (2, 7, 3) and isinstance(value, unicode): # pragma: no cover
-        value = value.encode(u'utf-8')
+    if isinstance(value, unicode):
+        value = value.encode('utf-8')
     parser = shlex.shlex(value)
     parser.whitespace += u','
     parser.whitespace_split = True
@@ -112,7 +113,9 @@ class RattailConfig(object):
         self.usedb = usedb
         if self.usedb is None:
             self.usedb = self.getbool('rattail.config', 'usedb', usedb=False, default=False)
-        self.preferdb = self.getbool('rattail.config', 'preferdb', usedb=False, default=False)
+        self.preferdb = preferdb
+        if self.usedb and self.preferdb is None:
+            self.preferdb = self.getbool('rattail.config', 'preferdb', usedb=False, default=False)
 
         # Attempt to detect lack of SQLAlchemy libraries etc.  This allows us
         # to avoid installing those on a machine which will not need to access
@@ -121,7 +124,7 @@ class RattailConfig(object):
         if self.usedb:
             try:
                 from rattail.db import Session
-            except ImportError:
+            except ImportError: # pragma: no cover
                 log.warning("config created with `usedb = True`, but can't import "
                             "`rattail.db.Session`, so setting `usedb = False` instead",
                             exc_info=True)
@@ -178,16 +181,19 @@ class RattailConfig(object):
         # Coerce all logged timestamps to the local timezone, if possible.
         logging.Formatter.converter = TimeConverter(self)
 
+        # Flush all current config to a single file, for input to fileConfig().
         path = temp_path(suffix='.conf')
         with open(path, 'wt') as f:
             self.parser.write(f)
+
         try:
             logging.config.fileConfig(path, disable_existing_loggers=False)
         except ConfigParser.NoSectionError as error:
             log.warning("tried to configure logging, but got NoSectionError: {0}".format(error))
         else:
             log.debug("configured logging")
-        os.remove(path)
+        finally:
+            os.remove(path)
 
     def setdefault(self, section, option, value):
         """
@@ -253,6 +259,21 @@ class RattailConfig(object):
             session.close()
         return value
 
+    def setdb(self, section, option, value, session=None):
+        """
+        Set a config value in the database settings table.  Note that the
+        ``value`` arg should be a Unicode object.
+        """
+        from rattail.db import api
+
+        close = False
+        if session is None:
+            session, close = self._session_factory()
+        api.save_setting(session, '{}.{}'.format(section, option), value)
+        if close:
+            session.commit()
+            session.close()
+
     def getbool(self, *args, **kwargs):
         """
         Retrieve a boolean value from config.
@@ -271,6 +292,17 @@ class RattailConfig(object):
             return value
         return int(value)
 
+    def getdate(self, *args, **kwargs):
+        """
+        Retrieve a date value from config.
+        """
+        value = self.get(*args, **kwargs)
+        if value is None:
+            return None
+        if isinstance(value, datetime.date):
+            return value
+        return datetime.datetime.strptime(value, '%Y-%m-%d').date()
+
     def getlist(self, *args, **kwargs):
         """
         Retrieve a list of string values from a single config option.
@@ -315,12 +347,48 @@ class RattailConfig(object):
             msg, option, section)
         raise ConfigurationError(msg)
 
+    ##############################
+    # convenience methods
+    ##############################
+
     def production(self):
         """
         Returns boolean indicating whether the config indicates production mode.
         """
         return self.getbool('rattail', 'production', default=False)
 
+    def workdir(self, require=False):
+        """
+        Returns boolean indicating whether the config indicates production mode.
+        """
+        get = self.require if require else self.get
+        return get('rattail', 'workdir')
+
+    def batch_filedir(self, key=None):
+        """
+        Returns path to root folder where batches (optionally of type 'key')
+        are stored.
+        """
+        path = os.path.abspath(self.require('rattail', 'batch.files'))
+        if key:
+            return os.path.join(path, key)
+        return path
+
+    def batch_filepath(self, key, uuid, filename, makedirs=False):
+        """
+        Returns absolute path to batch data file, generated from the given args.
+        """
+        rootdir = self.batch_filedir(key)
+        filedir = os.path.join(rootdir, uuid[:2], uuid[2:])
+        if makedirs and not os.path.exists(filedir):
+            os.makedirs(filedir)
+        return os.path.join(filedir, filename)
+
+    def datasync_url(self):
+        """
+        Returns configured URL for managing datasync daemon.
+        """
+        return self.get('rattail.datasync', 'url')
 
     ##############################
     # deprecated methods
