@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 """
 Handler for ${model_title} batches
 """
@@ -28,7 +29,7 @@ class ${model_name}Handler(FileBatchHandler):
         various lookups and business rules, as needed.
         """
 
-    def execute(self, batch, progress=None):
+    def execute(self, batch, **kwargs):
         """
         Execute the batch, whatever that means in your context.
         """
