@@ -27,4 +27,4 @@ DataSync Daemon
 from __future__ import unicode_literals, absolute_import
 
 from .watchers import DataSyncWatcher
-from .consumers import DataSyncConsumer, DataSyncImportConsumer
+from .consumers import DataSyncConsumer, DataSyncImportConsumer, NewDataSyncImportConsumer
