@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,13 +24,16 @@
 DataSync Watchers
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 
 class DataSyncWatcher(object):
     """
     Base class for all DataSync watchers.
     """
+    prunes_changes = False
+    retry_attempts = 1
+    retry_delay = 1 # seconds
 
     def __init__(self, config, key):
         self.config = config
@@ -55,3 +58,24 @@ class DataSyncWatcher(object):
         """
         Prune change records from the source database, if relevant.
         """
+
+    def process_changes(self, session, changes):
+        """
+        Process (consume) a batch of changes.
+        """
+
+
+class NullWatcher(DataSyncWatcher):
+    """
+    Null watcher, will never actually check for or report any changes.
+    """
+
+
+class ErrorTestWatcher(DataSyncWatcher):
+    """
+    Watcher which always raises an error when attempting to get changes.
+    Useful for testing error handling etc.
+    """
+
+    def get_changes(self, lastrun):
+        raise RuntimeError("Fake exception, to test error handling")
