@@ -45,23 +45,27 @@ if sqlalchemy:
         related to the SQLAlchemy-Continuum integration.
         """
 
-        def __init__(self, continuum_user=None, **kwargs):
+        def __init__(self, rattail_config=None, rattail_record_changes=False, continuum_user=None, **kwargs):
             """
             Custom constructor, to allow specifying the Continuum user at session
             creation.  If ``continuum_user`` is specified, its value will be passed
             to :meth:`set_continuum_user()`.
             """
             super(SessionBase, self).__init__(**kwargs)
+            self.rattail_config = rattail_config
+
+            # maybe record changes
+            if rattail_record_changes or getattr(self.bind, 'rattail_record_changes', False):
+                from rattail.db.changes import record_changes
+                record_changes(self, config=self.rattail_config)
+            else:
+                self.rattail_record_changes = False
+
             if continuum_user is None:
                 self.continuum_user = None
             else:
                 self.set_continuum_user(continuum_user)
 
-            # maybe record changes
-            if getattr(self.bind, '_rattail_record_changes', False):
-                from rattail.db.changes import record_changes
-                record_changes(self)
-
         def set_continuum_user(self, user_info):
             """
             Set the effective Continuum user for the session.
@@ -83,7 +87,7 @@ if sqlalchemy:
             self.continuum_user = user
 
 
-    Session = orm.sessionmaker(class_=SessionBase)
+    Session = orm.sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False)
 
 else: # no sqlalchemy
     Session = None
@@ -128,11 +132,11 @@ class ConfigExtension(BaseExtension):
             # Add Rattail database connection info to config.
             config.rattail_engines = get_engines(config)
             config.rattail_engine = config.rattail_engines.get('default')
-            Session.configure(bind=config.rattail_engine)
+            Session.configure(bind=config.rattail_engine, rattail_config=config)
 
             # TODO: This should be removed, it sets 'record changes' globally.
             configure_session(config, Session)
 
             # TODO: I have no idea if this works, probably not.
-            if config.getbool('rattail.db', 'versioning.enabled', default=False):
+            if config.getbool('rattail.db', 'versioning.enabled', default=False, usedb=False):
                 configure_versioning(config)
