@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-# -*- coding: utf-8  -*-
+# -*- coding: utf-8 -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2012 Lance Edgar
+#  Copyright © 2010-2015 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -21,11 +20,15 @@
 #  along with Rattail.  If not, see <http://www.gnu.org/licenses/>.
 #
 ################################################################################
-
 """
-``rattail.db.api`` -- Database API
+Database API
 """
 
-from .people import *
-from .products import *
-from .settings import *
+from rattail.db.api.people import get_employee_by_id
+from rattail.db.api.products import (
+    get_product_by_upc, get_product_by_code, get_product_by_vendor_code,
+    set_regular_price, set_current_sale_price)
+from rattail.db.api.settings import get_setting, save_setting
+from rattail.db.api.org import get_department, get_subdepartment
+from rattail.db.api.stores import get_store
+from rattail.db.api.vendors import get_vendor
