@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,32 +24,29 @@
 Products API
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 from sqlalchemy.orm.exc import NoResultFound
 
-from rattail.db import model
 from rattail import enum
+from rattail.db import model
 
 
-__all__ = ['get_product_by_upc', 'get_product_by_code']
-
-
-def get_product_by_upc(session, upc):
+def get_product_by_upc(session, upc, include_deleted=False):
     """
     Returns the :class:`rattail.Product` associated with ``upc`` (if found), or
     ``None``.
     """
-
-    q = session.query(model.Product)
-    q = q.filter(model.Product.upc == upc)
+    products = session.query(model.Product)
+    if not include_deleted:
+        products = products.filter(model.Product.deleted == False)
     try:
-        return q.one()
+        return products.filter(model.Product.upc == upc).one()
     except NoResultFound:
-        return None
+        pass
 
 
-def get_product_by_code(session, code):
+def get_product_by_code(session, code, include_deleted=False):
     """
     Locate a ``Product`` instance using a code value.
 
@@ -64,14 +61,13 @@ def get_product_by_code(session, code):
        This function will return the *first* product found, and does not warn
        if multiple products would have matched the search.
     """
-
-    q = session.query(model.Product)\
-        .outerjoin(model.ProductCode)\
-        .filter(model.ProductCode.code == code)
-    return q.first()
+    products = session.query(model.Product).join(model.ProductCode)
+    if not include_deleted:
+        products = products.filter(model.Product.deleted == False)
+    return products.filter(model.ProductCode.code == code).first()
 
 
-def get_product_by_vendor_code(session, code, vendor=None):
+def get_product_by_vendor_code(session, code, vendor=None, include_deleted=False):
     """
     Locate a product using a vendor item code, optionally restricted to a
     particular vendor.
@@ -89,12 +85,12 @@ def get_product_by_vendor_code(session, code, vendor=None):
        This function will return the *first* product found, and does not warn
        if multiple products would have matched the search.
     """
-    q = session.query(model.Product)\
-        .outerjoin(model.ProductCost)\
-        .filter(model.ProductCost.code == code)
+    products = session.query(model.Product).join(model.ProductCost)
     if vendor:
-        q = q.filter(model.ProductCost.vendor == vendor)
-    return q.first()
+        products = products.filter(model.ProductCost.vendor == vendor)
+    if not include_deleted:
+        products = products.filter(model.Product.deleted == False)
+    return products.filter(model.ProductCost.code == code).first()
 
 
 def set_regular_price(product, newprice, **kwargs):
