@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Authentication & Authorization
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import bcrypt
 
@@ -89,6 +89,13 @@ def guest_role(session):
     return special_role(session, 'f8a27c98965a11dfaff7001143047286', 'Guest')
 
 
+def authenticated_role(session):
+    """
+    Returns the "Authenticated" role.
+    """
+    return special_role(session, 'b765a9cc331a11e6ac2a3ca9f40bc550', "Authenticated")
+
+
 def grant_permission(role, permission):
     """
     Grant a permission to a role.
@@ -100,7 +107,7 @@ def grant_permission(role, permission):
         role.permissions.append(permission)
 
 
-def has_permission(session, principal, permission, include_guest=True):
+def has_permission(session, principal, permission, include_guest=True, include_authenticated=True):
     """
     Determine if a principal has been granted a permission.
 
@@ -118,6 +125,9 @@ def has_permission(session, principal, permission, include_guest=True):
        when checking permissions.  If ``False``, then Guest's permissions will
        *not* be consulted.
 
+    :param include_authenticated: Whether or not the "Authenticated" role
+       should be included when checking permissions.
+
     Note that if no ``principal`` is provided, and ``include_guest`` is set to
     ``False``, then no checks will actually be done, and the return value will
     be ``False``.
@@ -125,16 +135,13 @@ def has_permission(session, principal, permission, include_guest=True):
 
     if hasattr(principal, 'roles'):
         roles = list(principal.roles)
+        if include_authenticated:
+            roles.append(authenticated_role(session))
     elif principal is not None:
         roles = [principal]
     else:
         roles = []
 
-    # Admin always has permission.
-    admin = administrator_role(session)
-    if admin in roles:
-        return True
-
     if include_guest:
         roles.append(guest_role(session))
     for role in roles:
