@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,4 +24,7 @@
 Batch System
 """
 
-from .model import BatchMixin, FileBatchMixin, BatchRowMixin, ProductBatchRowMixin
+from __future__ import unicode_literals, absolute_import
+
+from .model import (BatchMixin, BaseFileBatchMixin, FileBatchMixin,
+                    BatchRowMixin, ProductBatchRowMixin)
