@@ -89,11 +89,12 @@ class ModelCacher(object):
         if prog:
             prog.destroy()
 
-        if self.omit_duplicates and self.duplicate_keys:
-            log.info("will prune {} duplicated keys from cache".format(len(self.duplicate_keys)))
-            for key in self.duplicate_keys:
-                log.debug("removing duplicated key from cache: {}".format(repr(key)))
-                del self.instances[key]
+        if self.duplicate_keys:
+            log.warning("found {} duplicated keys in cache".format(len(self.duplicate_keys)))
+            if self.omit_duplicates:
+                for key in self.duplicate_keys:
+                    log.debug("removing duplicated key from cache: {}".format(repr(key)))
+                    del self.instances[key]
 
         return self.instances
 
