@@ -32,8 +32,14 @@ from sqlalchemy.orm import object_mapper, RelationshipProperty
 from sqlalchemy.orm.interfaces import SessionExtension
 from sqlalchemy.orm.session import Session
 
+try:
+    from sqlalchemy.event import listen
+except ImportError:
+    listen = None # old SQLAlchemy; will have to work around that, below
+
 from rattail.db import model
 from rattail.core import get_uuid
+from rattail.util import load_object
 
 try:
     from rattail.db.continuum import versioning_manager
@@ -41,34 +47,41 @@ except ImportError:             # assume no continuum
     versioning_manager = None
 
 
-__all__ = ['record_changes']
-
 log = logging.getLogger(__name__)
 
 
-def record_changes(session, ignore_role_changes=True):
+def record_changes(session, recorder=None, config=None):
     """
-    Record all changes which occur within a session.
+    Record all relevant data changes which occur within a session.
 
     :param session: A :class:`sqlalchemy:sqlalchemy.orm.session.Session` class,
-       or an instance thereof.
-
-    :param ignore_role_changes: Whether changes involving roles and role
-       membership should be ignored.  This defaults to ``True``, which means
-       each database will be responsible for maintaining its own role (and by
-       extension, permissions) data.
+       or instance thereof.
     """
-    recorder = ChangeRecorder(ignore_role_changes)
-    try:
-        from sqlalchemy.event import listen
-    except ImportError: # pragma: no cover
+    if isinstance(recorder, ChangeRecorder):
+        pass
+    elif callable(recorder):
+        recorder = recorder()
+    elif recorder is None:
+        if config:
+            spec = config.get('rattail.db', 'changes.recorder', usedb=False)
+            if spec:
+                recorder = load_object(spec)()
+        if not recorder:
+            recorder = ChangeRecorder()
+    else:
+        raise ValueError("Invalid 'recorder' parameter: {}".format(repr(recorder)))
+
+    if listen:
+        listen(session, 'before_flush', recorder)
+    else:
         extension = ChangeRecorderExtension(recorder)
         if isinstance(session, Session):
             session.extensions.append(extension)
         else:
             session.configure(extension=extension)
-    else:
-        listen(session, u'before_flush', recorder)
+
+    session.rattail_record_changes = True
+    session.rattail_change_recorder = recorder
 
 
 class ChangeRecorder(object):
@@ -79,41 +92,67 @@ class ChangeRecorder(object):
     which will in turn be used by the database synchronizer to manage change
     data propagation.
     """
-
-    def __init__(self, ignore_role_changes=True):
-        self.ignore_role_changes = ignore_role_changes
-        self.ignored_classes = (model.Setting, model.Change, model.DataSyncChange)
+    ignored_classes = (
+        model.Setting,
+        model.Change,
+        model.DataSyncChange,
+    )
 
     def __call__(self, session, flush_context, instances):
         """
         Method invoked when session ``before_flush`` event occurs.
         """
-        # TODO: Not sure if our event replaces the one registered by Continuum,
-        # or what.  But this appears to be necessary to keep that system
-        # working when we enable ours...
-        if versioning_manager:
-            versioning_manager.before_flush(session, flush_context, instances)
+        # TODO: what a mess, need to look into this again at some point...
+        # # TODO: Not sure if our event replaces the one registered by Continuum,
+        # # or what.  But this appears to be necessary to keep that system
+        # # working when we enable ours...
+        # if versioning_manager:
+        #     versioning_manager.before_flush(session, flush_context, instances)
 
-        for instance in session.deleted:
-            if not isinstance(instance, self.ignored_classes):
-                # TODO: Is this hacky?  Seems like maybe so...
-                if isinstance(instance, (model.PersonEmailAddress, model.PersonPhoneNumber, model.PersonMailingAddress)):
-                    self.record_change(session, instance.person)
-                if isinstance(instance, (model.EmployeeStore, model.EmployeeDepartment)):
-                    self.record_change(session, instance.employee)
-                self.record_change(session, instance, type_='deleted')
-        for instance in session.new:
-            if not isinstance(instance, self.ignored_classes):
-                self.record_change(session, instance, type_='new')
-        for instance in session.dirty:
-            if not isinstance(instance, self.ignored_classes) and session.is_modified(instance, passive=True):
+        for obj in session.deleted:
+            if not self.ignore_object(obj):
+                self.process_deleted_object(session, obj)
+        for obj in session.new:
+            if not self.ignore_object(obj):
+                self.process_new_object(session, obj)
+        for obj in session.dirty:
+            if not self.ignore_object(obj) and session.is_modified(obj, passive=True):
                 # Orphaned objects which really are pending deletion show up in
                 # session.dirty instead of session.deleted, hence this check.
-                # See also https://groups.google.com/d/msg/sqlalchemy/H4nQTHphc0M/Xr8-Cgra0Z4J
-                if self.is_deletable_orphan(instance):
-                    self.record_change(session, instance, type_='deleted')
+                # https://groups.google.com/d/msg/sqlalchemy/H4nQTHphc0M/Xr8-Cgra0Z4J
+                if self.is_deletable_orphan(obj):
+                    self.process_deleted_object(session, obj)
                 else:
-                    self.record_change(session, instance)
+                    self.process_dirty_object(session, obj)
+
+    def ignore_object(self, obj):
+        """
+        Return ``True`` if changes for the given object should be ignored.
+        """
+        return isinstance(obj, self.ignored_classes)
+
+    def process_new_object(self, session, obj):
+        """
+        Record changes as appropriate, for the given 'new' object.
+        """
+        self.record_rattail_change(session, obj, type_='new')
+
+    def process_dirty_object(self, session, obj):
+        """
+        Record changes as appropriate, for the given 'dirty' object.
+        """
+        self.record_rattail_change(session, obj, type_='dirty')
+
+    def process_deleted_object(self, session, obj):
+        """
+        Record changes as appropriate, for the given 'deleted' object.
+        """
+        # TODO: Is this hacky?  Seems like maybe so...
+        if isinstance(obj, (model.PersonEmailAddress, model.PersonPhoneNumber, model.PersonMailingAddress)):
+            self.record_rattail_change(session, obj.person, type_='dirty')
+        if isinstance(obj, (model.EmployeeStore, model.EmployeeDepartment)):
+            self.record_rattail_change(session, obj.employee, type_='dirty')
+        self.record_rattail_change(session, obj, type_='deleted')
 
     def is_deletable_orphan(self, instance):
         """
@@ -144,7 +183,7 @@ class ChangeRecorder(object):
 
         return False
 
-    def record_change(self, session, instance, type_='dirty'):
+    def record_rattail_change(self, session, instance, type_='dirty'):
         """
         Record a change record in the database.
 
@@ -155,6 +194,7 @@ class ChangeRecorder(object):
         :returns: ``True`` if a change was recorded, or ``False`` if it was
            ignored.
         """
+        # TODO: this check is now redundant due to `ignore_object()`
         # No need to record changes for changes.
         if isinstance(instance, (model.Change, model.DataSyncChange)):
             return False
@@ -168,22 +208,29 @@ class ChangeRecorder(object):
         if not hasattr(instance, 'uuid'):
             return False
 
-        # Ignore Role instances, if so configured.
-        if self.ignore_role_changes and isinstance(instance, (model.Role, model.UserRole)):
-            return False
-
         # Provide an UUID value, if necessary.
         self.ensure_uuid(instance)
 
         # Record the change.
-        change = model.Change(class_name=instance.__class__.__name__,
-                              instance_uuid=instance.uuid,
-                              deleted=type_ == 'deleted')
-        session.add(change)
+        self.record_change(session, quiet=True,
+                           class_name=instance.__class__.__name__,
+                           instance_uuid=instance.uuid,
+                           deleted=type_ == 'deleted')
         log.debug("recorded change for {} {} {}: {}".format(
             type_, instance.__class__.__name__, instance.uuid, instance))
         return True
 
+    def record_change(self, session, quiet=False, **kwargs):
+        """
+        Record a change, by creating a new change record in the session.
+        """
+        session.add(model.Change(**kwargs))
+        if not quiet:
+            log.debug("recorded {} for {} with key: {}".format(
+                'deletion' if kwargs.get('deleted') else 'change',
+                kwargs.get('class_name'),
+                kwargs.get('object_key', kwargs.get('instance_uuid'))))
+
     def ensure_uuid(self, instance):
         """
         Ensure the given instance has a UUID value.
@@ -222,7 +269,7 @@ class ChangeRecorder(object):
         log.error("unexpected scenario; generated new UUID for instance: {0}".format(repr(instance)))
 
 
-class ChangeRecorderExtension(SessionExtension): # pragma: no cover
+class ChangeRecorderExtension(SessionExtension):
     """
     Session extension for recording changes.
 
