@@ -65,7 +65,7 @@ def engine_from_config(configuration, prefix='sqlalchemy.', **kwargs):
         kwargs.setdefault('poolclass', load_object(config[key]))
         del config[key]
 
-    # Store 'record_changes' flag as private attr on engine.
+    # Store 'record_changes' flag as attribute on engine.
     record_changes = False
     key = '{}record_changes'.format(prefix)
     if key in config:
@@ -75,7 +75,7 @@ def engine_from_config(configuration, prefix='sqlalchemy.', **kwargs):
 
     engine = engine_from_config(config, prefix, **kwargs)
     if record_changes:
-        engine._rattail_record_changes = True
+        engine.rattail_record_changes = True
     return engine
 
 
@@ -128,17 +128,16 @@ def get_default_engine(config, section='rattail.db'):
     return get_engines(config, section=section).get('default')
 
 
+# TODO: Deprecate/remove this.
 def configure_session(config, session):
     """
     Configure a session factory or instance.  Currently all this does is
-    install the hook to record changes, if so config so dictates.
+    install the hook to record changes, if config so dictates.
     """
     from rattail.db.changes import record_changes
 
     if config.getbool('rattail.db', 'changes.record', usedb=False):
-        ignore_role_changes = config.getbool(
-            'rattail.db', 'changes.ignore_roles', default=True, usedb=False)
-        record_changes(session, ignore_role_changes)
+        record_changes(session, config=config)
 
 
 def configure_versioning(config, manager=None, plugins=None, **kwargs):
