@@ -36,9 +36,11 @@ from .customers import (Customer, CustomerPhoneNumber, CustomerEmailAddress,
 from .org import Department, Subdepartment, Category, Family, ReportCode, DepositLink
 from .employees import (Employee, EmployeePhoneNumber, EmployeeEmailAddress,
                         EmployeeStore, EmployeeDepartment)
+from .shifts import ScheduledShift, WorkedShift
 
 from .vendors import Vendor, VendorPhoneNumber, VendorEmailAddress, VendorContact
 from .products import Brand, Tax, Product, ProductCode, ProductCost, ProductPrice
+from .purchase import Purchase, PurchaseItem
 
 from .messages import Message, MessageRecipient
 
@@ -47,7 +49,11 @@ from .batches import Batch, BatchColumn, BatchRow
 from .labels import LabelProfile
 from .bouncer import EmailBounce
 
-from rattail.db.batch.model import (BatchMixin, FileBatchMixin,
+from rattail.db.batch.model import (BatchMixin, BaseFileBatchMixin, FileBatchMixin,
                                     BatchRowMixin, ProductBatchRowMixin)
+from rattail.db.batch.handheld.model import HandheldBatch, HandheldBatchRow
+from rattail.db.batch.inventory.model import InventoryBatch, InventoryBatchRow
+from rattail.db.batch.labels.model import LabelBatch, LabelBatchRow
+from rattail.db.batch.purchase.model import PurchaseBatch, PurchaseBatchRow
 from rattail.db.batch.vendorcatalog.model import VendorCatalog, VendorCatalogRow
 from rattail.db.batch.vendorinvoice.model import VendorInvoice, VendorInvoiceRow
