@@ -51,7 +51,7 @@ class Customer(Base):
     email_preference = sa.Column(sa.Integer())
 
     def __unicode__(self):
-        return unicode(self.name or self.person)
+        return unicode(self.name or self.person or '')
 
     def add_email_address(self, address, type='Home'):
         email = CustomerEmailAddress(address=address, type=type)
