@@ -479,8 +479,11 @@ class Importer(object):
 
     def create_instance(self, key, data):
         instance = self.new_instance(key)
-        self.session.add(instance)
-        return self.update_instance(instance, data)
+        if instance:
+            instance = self.update_instance(instance, data)
+            if instance:
+                self.session.add(instance)
+                return instance
 
     def new_instance(self, key):
         """
@@ -500,7 +503,6 @@ class Importer(object):
             if field in self.fields:
                 if not instance_data or instance_data[field] != data[field]:
                     setattr(instance, field, data[field])
-        self.session.flush()
         return instance
 
 
@@ -566,12 +568,15 @@ class BulkPostgreSQLImporter(Importer):
 
     def import_data(self, args, progress=None):
         self._setup(args, progress)
-        self.data_buffer = open(self.data_path, 'wb')
+        self.open_data_buffers()
         data = self.normalize_source_data()
         created = self._import_create(data, args)
         self.teardown()
         return created
 
+    def open_data_buffers(self):
+        self.data_buffer = open(self.data_path, 'wb')
+
     def teardown(self):
         self.data_buffer.close()
 
@@ -604,12 +609,12 @@ class BulkPostgreSQLImporter(Importer):
 
     def commit_create(self):
         log.info("copying {} data from buffer to PostgreSQL".format(self.model_name))
-        self.seek_data_buffer()
+        self.seek_data_buffers()
         cursor = self.session.connection().connection.cursor()
         cursor.copy_from(self.data_buffer, self.model_table.name, columns=self.fields)
         log.debug("PostgreSQL data copy completed")
 
-    def seek_data_buffer(self):
+    def seek_data_buffers(self):
         self.data_buffer.close()
         self.data_buffer = open(self.data_path, 'rb')
 
