@@ -32,6 +32,7 @@ from sqlalchemy import orm
 
 from rattail.db import model, cache, auth
 from rattail.db.newimporting import Importer
+from rattail.db.util import normalize_phone_number, format_phone_number
 
 
 log = logging.getLogger(__name__)
@@ -107,12 +108,22 @@ class PersonPhoneNumberImporter(Importer):
     @property
     def supported_fields(self):
         return self.simple_fields + [
+            'normalized_number',
             'preferred',
         ]
 
+    def normalize_number(self, number):
+        return normalize_phone_number(number)
+
+    def format_number(self, number):
+        return format_phone_number(number)
+
     def normalize_instance(self, phone):
         data = super(PersonPhoneNumberImporter, self).normalize_instance(phone)
-        data['preferred'] = phone.preference == 1
+        if 'normalized_number' in self.fields:
+            data['normalized_number'] = self.normalize_number(phone.number)
+        if 'preferred' in self.fields:
+            data['preferred'] = phone.preference == 1
         return data
 
     def update_instance(self, phone, data, inst_data=None):
@@ -323,6 +334,9 @@ class EmployeeImporter(Importer):
         data = super(EmployeeImporter, self).normalize_instance(employee)
 
         if set(self.fields) | set(['customer_id', 'first_name', 'last_name', 'full_name']):
+            if not employee.person:
+                self.session.flush()
+                assert employee.person
             person = employee.person
             self.newval(data, 'first_name', person.first_name)
             self.newval(data, 'last_name', person.last_name)
@@ -469,6 +483,20 @@ class EmployeePhoneNumberImporter(Importer):
     model_class = model.EmployeePhoneNumber
 
 
+class ScheduledShiftImporter(Importer):
+    """
+    Imports employee scheduled shifts.
+    """
+    model_class = model.ScheduledShift
+
+
+class WorkedShiftImporter(Importer):
+    """
+    Imports shifts worked by employees.
+    """
+    model_class = model.WorkedShift
+
+
 class CustomerImporter(Importer):
     """
     Customer data importer.
