@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,15 @@
 Database Synchronization for Windows
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import sys
 import logging
 import threading
 
-from ...win32.service import Service
-from .. import get_default_engine
-from . import get_sync_engines, synchronize_changes
+from rattail.db.config import get_default_engine
+from rattail.db.sync import get_sync_engines, synchronize_changes
+from rattail.win32.service import Service
 
 
 log = logging.getLogger(__name__)
