@@ -85,6 +85,26 @@ EMAIL_PREFERENCE = {
     }
 
 
+HANDHELD_DEVICE_TYPE_MOTOROLA           = 'motorola'
+HANDHELD_DEVICE_TYPE_PALMOS             = 'palmos'
+
+HANDHELD_DEVICE_TYPE = {
+    HANDHELD_DEVICE_TYPE_MOTOROLA       : "Motorola",
+    HANDHELD_DEVICE_TYPE_PALMOS         : "PalmOS",
+}
+
+
+INVENTORY_MODE_REPLACE          = 1
+INVENTORY_MODE_REPLACE_ADJUST   = 2
+INVENTORY_MODE_ADJUST           = 3
+
+INVENTORY_MODE = {
+    INVENTORY_MODE_REPLACE              : "Replace only",
+    INVENTORY_MODE_REPLACE_ADJUST       : "Replace then adjust",
+    INVENTORY_MODE_ADJUST               : "Adjust only",
+}
+
+
 MESSAGE_STATUS_INBOX            = 1
 MESSAGE_STATUS_ARCHIVE          = 2
 
@@ -124,6 +144,21 @@ PRICE_TYPE = {
     }
 
 
+PURCHASE_STATUS_NEW             = 1
+PURCHASE_STATUS_ORDERED         = 10
+PURCHASE_STATUS_RECEIVED        = 20
+PURCHASE_STATUS_COSTED          = 30
+PURCHASE_STATUS_PAID            = 40
+
+PURCHASE_STATUS = {
+    PURCHASE_STATUS_NEW         : "new/pending",
+    PURCHASE_STATUS_ORDERED     : "ordered",
+    PURCHASE_STATUS_RECEIVED    : "received",
+    PURCHASE_STATUS_COSTED      : "costed",
+    PURCHASE_STATUS_PAID        : "paid",
+}
+
+
 # These values are taken from the SIL standard.
 UNIT_OF_MEASURE_NONE                    = '00'
 UNIT_OF_MEASURE_EACH                    = '01'
