@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -93,6 +93,10 @@ class RecipientsNotFound(ConfigurationError):
     def __init__(self, key):
         self.key = key
 
+    def __str__(self):
+        return (b"No recipients found in config for '{0}' emails.  Please set '{0}.to' "
+                "(or 'default.to') in the [rattail.mail] section.".format(self.key))
+
     def __unicode__(self):
         return ("No recipients found in config for '{0}' emails.  Please set '{0}.to' "
                 "(or 'default.to') in the [rattail.mail] section.".format(self.key))
