@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -27,7 +27,10 @@ This subpackage contains various tasks and associated functions for use with
 Fabric deployment and maintenance.
 """
 
-from .core import put, upload_template, make_deploy, mkdir, get_debian_version, rsync
-from .core import make_system_user, add_mail_alias
+from __future__ import unicode_literals, absolute_import
+
+from .core import put, upload_template, make_deploy, mkdir, rsync
+from .core import make_system_user, add_mail_alias, set_timezone, agent_sudo
+from .core import get_debian_version, get_ubuntu_version
 
 from .python import workon, cdvirtualenv
