@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,13 +24,17 @@
 File Monitor Actions
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import os
 import sys
 import time
 import Queue
+import socket
 import logging
+from traceback import format_exception
+
+from rattail.mail import send_email
 
 
 log = logging.getLogger(__name__)
@@ -137,8 +141,18 @@ def invoke_action(action, path):
 
             # If we've reached our final attempt, stop retrying.
             if attempts >= action.retry_attempts:
-                log.exception(u"attempt #{0} failed for action {1} (giving up) on "
-                              u"file: {2}".format(attempts, repr(action.spec), repr(path)))
+                log.debug("attempt #{} failed for action '{}' (giving up) on "
+                          "file: {}".format(attempts, action.spec, path),
+                          exc_info=True)
+                exc_type, exc, traceback = sys.exc_info()
+                send_email(action.config, 'filemon_action_error', {
+                    'hostname': socket.gethostname(),
+                    'path': path,
+                    'action': action,
+                    'attempts': attempts,
+                    'error': exc,
+                    'traceback': ''.join(format_exception(exc_type, exc, traceback)).strip(),
+                })
                 raise
 
             # If this exception is not the first, and is of a different type
