@@ -128,12 +128,16 @@ def watch_directory(profile, path):
         log.error(u"can't open directory with CreateFile(): {0}".format(repr(path)))
         return
 
+    dwNotifyFilter = win32con.FILE_NOTIFY_CHANGE_FILE_NAME
+    if profile.watch_locks:
+        dwNotifyFilter |= win32con.FILE_NOTIFY_CHANGE_DIR_NAME
+
     while True:
         results = win32file.ReadDirectoryChangesW(
             hDir,
             1024,
             False,
-            win32con.FILE_NOTIFY_CHANGE_FILE_NAME)
+            dwNotifyFilter)
 
         log.debug(u"ReadDirectoryChangesW() returned: {0}".format(repr(results)))
         for action, fname in results:
@@ -145,7 +149,8 @@ def watch_directory(profile, path):
                     queue = True
             else:
                 if action in (winnt.FILE_ACTION_ADDED, winnt.FILE_ACTION_RENAMED_NEW_NAME):
-                    queue = True
+                    if os.path.isfile(fpath): # just in case..ignore folders etc.
+                        queue = True
             if queue:
                 log.debug(u"queueing {0} file: {1}".format(repr(profile.key), repr(fpath)))
                 profile.queue.put(fpath)
