@@ -107,6 +107,39 @@ class GPC(object):
     def __unicode__(self):
         return u'%014d' % self.value
 
+    @property
+    def data_str(self):
+        """
+        Returns the "data" for the barcode as unicode string, i.e. minus check
+        digit and also with all leading zeroes removed.  A visual is maybe
+        helpful here::
+
+           >>> upc = GPC('7430500132', calc_check_digit='upc')
+           >>> print(repr(upc))
+           GPC('00074305001321')
+           >>> print(repr(upc.data_str))
+           u'7430500132'
+
+        Note that in this case the ``data_str`` value is the same as was
+        originally provided to the constructor, but that isn't always the case.
+        """
+        return unicode(int(self))[:-1]
+
+    @property
+    def data_length(self):
+        """
+        Returns the length of the "data" for the barcode.  This is just a
+        convenience that returns ``len(self.data_str)``.
+        """
+        return len(self.data_str)
+
+    @property
+    def type2_upc(self):
+        """
+        Returns boolean indicating whether the barcode has "type 2" UPC data.
+        """
+        return self.data_str.startswith('2') and self.data_length == 11
+
     def pretty(self):
         """
         Returns the UPC as a somewhat more human-readable string.  Basically
