@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2015 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,7 +24,7 @@
 Time Utilities
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import datetime
 import warnings
@@ -105,10 +105,13 @@ def timezone(config, key='default'):
     return pytz.timezone(zone)
 
 
-def make_utc(time, tzinfo=False):
+def make_utc(time=None, tzinfo=False):
     """
-    Convert a timezone-aware time back to a naive UTC equivalent.
+    Convert a timezone-aware time back to a naive UTC equivalent.  If no time
+    is specified, the current time is assumed.
     """
+    if time is None:
+        time = datetime.datetime.utcnow()
     if time.tzinfo:
         utctime = pytz.utc.normalize(time.astimezone(pytz.utc))
     else:
@@ -116,3 +119,14 @@ def make_utc(time, tzinfo=False):
     if tzinfo:
         return utctime
     return utctime.replace(tzinfo=None)
+
+
+def get_sunday(date):
+    """
+    Return a ``datetime.date`` instance corresponding to Sunday of the given
+    week, according to the ``date`` parameter.
+    """
+    weekday = date.weekday()
+    if weekday == 6: # Sunday
+        return date
+    return date - datetime.timedelta(days=weekday + 1)
