@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2014 Lance Edgar
+#  Copyright © 2010-2016 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,10 @@
 Utilities
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
 import sys
+import subprocess
 
 from pkg_resources import iter_entry_points
 
@@ -36,6 +37,19 @@ except ImportError: # pragma no cover
     from ordereddict import OrderedDict
 
 
+def capture_output(command):
+    """
+    Runs ``command`` and returns any output it produces.
+    """
+    # We *need* to pipe ``stdout`` because that's how we capture the output of
+    # the ``hg`` command.  However, we must pipe *all* handles in order to
+    # prevent issues when running as a GUI but *from* the Windows console.  See
+    # also: http://bugs.python.org/issue3905
+    kwargs = dict(stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    output = subprocess.Popen(command, **kwargs).communicate()[0]
+    return output
+
+
 def import_module_path(module_path):
     """
     Import an arbitrary Python module.
@@ -101,3 +115,41 @@ def load_entry_points(group):
     for entry_point in iter_entry_points(group):
         entry_points[entry_point.name] = entry_point.load()
     return entry_points
+
+
+def prettify(text):
+    """
+    Return a "prettified" version of text.
+    """
+    text = text.replace('_', ' ')
+    text = text.replace('-', ' ')
+    words = text.split()
+    return ' '.join([x.capitalize() for x in words])
+
+
+def progress_loop(func, items, factory, *args, **kwargs):
+    """
+    This will iterate over ``items`` and call ``func`` for each.  If a progress
+    ``factory`` kwarg is provided, then a progress instance will be created and
+    updated along the way.
+    """
+    message = kwargs.pop('message', None)
+    count = kwargs.pop('count', None)
+    if count is None:
+        count = len(items)
+    if not count:
+        return True
+
+    prog = None
+    if factory:
+        prog = factory(message, count)
+
+    canceled = False
+    for i, item in enumerate(items, 1):
+        func(item, i, *args, **kwargs)
+        if prog and not prog.update(i):
+            canceled = True
+            break
+    if prog:
+        prog.destroy()
+    return not canceled
