@@ -74,10 +74,10 @@ class InvoiceParser(object):
         if isinstance(value, (Decimal, int)):
             return value
         if isinstance(value, float):
-            value = "{{0:0.{0}f}}".format(scale).format(value)
-        else:
-            value = value.strip()
-        return Decimal(value)
+            return Decimal("{{:0.{}f}}".format(scale).format(value))
+        value = value.strip()
+        if value:
+            return Decimal(value)
 
     def int_(self, value):
         """
